@@ -370,13 +370,11 @@ void SpriteSet::getAttribute(SceneNode* subscene, AttribID attrib, int first, in
   }
 }
 
-String SpriteSet::getTextAttribute(SceneNode* subscene, AttribID attrib, int index)
+std::string SpriteSet::getTextAttribute(SceneNode* subscene, AttribID attrib, int index)
 {
   int n = getAttributeCount(subscene, attrib);
   if (index < n && attrib == TYPES) {
-    char* buffer = R_alloc(20, 1);    
-    scene->get_shape(shapes[index])->getTypeName(buffer, 20);
-    return String(static_cast<int>(strlen(buffer)), buffer);
+    return scene->get_shape(shapes[index])->getTypeName();
   } else
     return Shape::getTextAttribute(subscene, attrib, index);
 }
